@@ -90,13 +90,13 @@ df_ram_size <- function() {
         }
       } 
     } else {
-      #ram_size = as.numeric(system('grep MemTotal /proc/meminfo', ignore.stdout = TRUE) / 1024)
       os = R.version$os
       if (length(grep("^darwin", os))) {
         a = substring(system("sysctl hw.memsize", intern = TRUE), 13)
-      } else {
-        a = system('grep MemTotal /proc/meminfo', intern = TRUE)
-      }
+      } #else {
+        # This would work but is not allowed by CRAN
+        #a = system('grep MemTotal /proc/meminfo', intern = TRUE)
+      #}
       l = strsplit(a, " ")[[1]]
       l = as.numeric(l[length(l)-1])
       ram_size = l/1024^2
